==> datafield-1.0.22.tar.gz: datafield/src/Plugin/DataField/FieldWidget/FileWidget.php <==
<?php

namespace Drupal\datafield\Plugin\DataField\FieldWidget;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\datafield\Plugin\DataFieldWidgetInterface;

/**
 * Plugin implementation of the 'file_generic' widget.
 *
 * @FieldWidget(
 *   id = "managed_file",
 *   label = @Translation("Uploading and saving file"),
 *   field_types = {
 *     "file",
 *     "entity_reference",
 *   },
 * )
 */
class FileWidget implements DataFieldWidgetInterface {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormElement(&$element, $item = NULL, $setting = []) {
    $fieldName = str_replace('field_', '', $element['#field_name']);
    $element['#upload_location'] = 'public://' . $fieldName . '/';
    if (!empty($element["#default_value"]) && !is_array($element["#default_value"])) {
      $element["#default_value"] = [$element["#default_value"]];
    }
    if (!empty($element["#field_settings"]["file_directory"])) {
      $element['#upload_location'] = 'public://' . $element["#field_settings"]["file_directory"] . '/';
    }
    if (!empty($element["#field_settings"]["file_extensions"])) {
      $setting["file_extensions"] = str_replace(
        [',', '  '], ' ',
        $element["#field_settings"]["file_extensions"]
      );
      $element['#upload_validators'] = [
        'file_validate_extensions' => [$setting["file_extensions"]],
      ];
    }
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues($value, array $form, FormStateInterface $form_state) {
    $entityType = $form["#field_settings"]["entity_reference_type"] ?? 'file';
    $checkEntityFile = in_array($entityType, ['file', 'image']);
    if ($checkEntityFile && is_array($value)) {
      return current($value);
    }
    return $value;
  }

}

==> datafield-2.0.0-rc5.tar.gz: datafield/src/Plugin/DataField/FieldWidget/FileWidget.php <==
<?php

namespace Drupal\datafield\Plugin\DataField\FieldWidget;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\datafield\Plugin\DataFieldWidgetInterface;
use Drupal\file\Entity\File;

/**
 * Plugin implementation of the 'file_generic' widget.
 *
 * @FieldWidget(
 *   id = "managed_file",
 *   label = @Translation("Uploading and saving file"),
 *   field_types = {
 *     "file",
 *     "entity_reference",
 *   },
 * )
 */
class FileWidget implements DataFieldWidgetInterface {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormElement(&$element, $item = NULL, $setting = []) {
    $fieldName = str_replace('field_', '', $element['#field_name']);
    $element['#upload_location'] = 'public://' . $fieldName . '/';
    $element['#process_default_value'] = FALSE;
    if (!empty($element["#default_value"]) && !is_array($element["#default_value"])) {
      $element["#default_value"] = [$element["#default_value"]];
    }
    if (!empty($element["#field_settings"]["file_directory"])) {
      $element['#upload_location'] = 'public://' . $element["#field_settings"]["file_directory"] . '/';
    }
    if (!empty($element["#field_settings"]["file_extensions"])) {
      $setting["file_extensions"] = str_replace(
        [',', '  '], ' ',
        $element["#field_settings"]["file_extensions"]
      );
      $element['#upload_validators'] = [
        'file_validate_extensions' => [$setting["file_extensions"]],
      ];
    }
    $element['#parents'] = [
      $element['#field_name'],
      $element['#delta'],
      $element["#field_storage"]["name"],
    ];
    $element['#progress_indicator'] = 'throbber';
  }

  /**
   * {@inheritdoc}
   */
  public function errorElement(array $element, ConstraintViolationInterface $violation, array $form, FormStateInterface $form_state) {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues($value, array $form, FormStateInterface $form_state) {
    $entityType = $form["#field_settings"]["entity_reference_type"] ?? 'file';
    $checkEntityFile = in_array($entityType, ['file', 'image']);
    if ($checkEntityFile && is_array($value)) {
      $fid = current($value);
      // Set file to permanent .
      $file = File::load($fid);
      $status = $file->get('status')->value;
      if (!$status) {
        $file->set('status', TRUE)->save();
      }

      return $fid;
    }
    return $value;
  }

}
